# numpy_table

This project implements a simple implementation of a dataframe using numpy arrays as its basic unit. The goal was to have a syntax simpler than pandas, and be able to use numpy in the columns of the dataframe directly.

## Authors and acknowledgment
Carlos Molinero

## License
MIT license

## Project status
This is a very early stage implementation, I do not recommend using it yet, I have published it for my personal use.